/*
 * Copyright 2008 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package de.timefinder.core;

import de.timefinder.core.springrc.MyApplicationLauncher;
import de.timefinder.core.util.ApplicationSettings;
import java.io.FileInputStream;
import java.util.logging.LogManager;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.richclient.application.support.DefaultApplicationDescriptor;

/**
 * This is the main entry point for the TimeFinder application via spring rc
 */
public class Startup {

    public static void main(String[] args) {
        new Startup().start();
    }

    /**
     * This method should be used only for testing!
     * and for Startup class
     */
    public static void initLogging() {
        try {
            LogManager.getLogManager().readConfiguration(
                    new FileInputStream(new ApplicationSettings().getLogPropertiesFile()));
        } catch (Exception ex) {
            ex.printStackTrace();
        }
    }
    private MyApplicationLauncher launcher;
    private Log logger;
    // we need these strings right here, to show the application version at the very first!
    // e.g. in cases where application context loading fails
    private final static String version = "v5";
    private final static String buildId = "2009-12-07";

    public void start() {
        initLogging();
        logger = LogFactory.getLog(Startup.class);

        logger.info("Java Version:" + System.getProperty("java.version"));
        logger.info("Application Version: " + version + " " + buildId);

        // In order to launch the platform, we have to construct an
        // application context that defines the beans (services) and
        // wiring. This is pretty much straight Spring.
        String rootCtx = "/de/timefinder/core/ctx";

        // The startup context defines elements that should be available
        // quickly such as a splash screen image.
        String startupContextPath = rootCtx + "/startup-context.xml";
        String richclientApplicationContextPath = rootCtx + "/application-context.xml";

        // The ApplicationLauncher is responsible for loading the contexts,
        // presenting the splash screen, initializing the Application
        // singleton instance, creating the application window to display
        // the initial page.
        try {
            launcher = new MyApplicationLauncher(startupContextPath,
                    new String[]{richclientApplicationContextPath});
            DefaultApplicationDescriptor appDescr = launcher.getApplicationDescriptor();
            appDescr.setVersion(version);
            appDescr.setBuildId(buildId);
        } catch (Throwable e) {
            logger.error("RuntimeException during startup", e);
        }
    }

    public void stop() {
        System.out.println("STOP");
//        launcher.close(true, 0);
    }
}
