package de.timefinder.core.io;

import de.pannous.xvantage.core.parsing.Parsing;
import de.timefinder.data.DBInterface;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.w3c.dom.Node;

/**
 * @author Peter Karich, peat_hal 'at' users 'dot' sourceforge 'dot' net
 */
public class TextCollectionParsing implements Parsing {

    private Log logger = LogFactory.getLog(getClass());
    private String idSeparator;
    private Map<Long, Object> simpleDao;
    private Class<DBInterface> type;

    public TextCollectionParsing(String idSeparator, Map<Long, Object> simpleDao, Class<DBInterface> type) {
        this.idSeparator = idSeparator;
        this.simpleDao = simpleDao;
        this.type = type;

        if (simpleDao == null) {
            throw new NullPointerException("No dao found for class: " + type.getName());
        }
    }

    public void setIdSeparator(String idSeparator) {
        this.idSeparator = idSeparator;
    }

    public void setType(Class<DBInterface> type) {
        this.type = type;
    }

    @Override
    public Object parse(Node node) {
        String content = node.getTextContent().trim();
        List list = new ArrayList();

        for (String str : content.split(idSeparator)) {
            Long id = null;
            try {
                id = Long.parseLong(str.trim());

            } catch (Exception ex) {
                logger.fatal("Couldn't parse id: " + type, ex);
                continue;
            }
            Object obj = simpleDao.get(id);
            if (obj == null) {
                try {
                    obj = type.newInstance();
                    simpleDao.put(id, obj);
                } catch (Exception ex) {
                    logger.fatal("Couldn't create obj of type: " + type, ex);
                    continue;
                }
            }

            list.add(obj);
        }

        return list;
    }
}
