/*
 *  Copyright 2009 Peter Karich, peat_hal ‘at’ users ‘dot’ sourceforge ‘dot’ net.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *  under the License.
 */
package de.timefinder.core.io.xml;

import com.thoughtworks.xstream.XStream;
import de.timefinder.algo.DataPoolSettings;
import de.timefinder.data.DataPool;
import de.timefinder.data.DBInterface;
import de.timefinder.data.Event;
import de.timefinder.data.Feature;
import de.timefinder.data.Location;
import de.timefinder.data.Person;
import de.timefinder.data.Role;
import de.timefinder.data.access.Dao;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * Class to help with serialization through xstream
 *
 * @author Peter Karich, peat_hal ‘at’ users ‘dot’ sourceforge ‘dot’ net
 */
public abstract class AbstractXStreamHelper {

    protected Log log = LogFactory.getLog(getClass());
    protected XStream xstream = new XStream();
    protected XStreamReadFromXml xStreamReader;
    // this is the external list we get via injection (export) or want to fill (import)
    protected DataPool dataPool;
    // this is the variable which is necessary to serialize the dataPool via xstream
    protected List<MyArrayList<? extends DBInterface>> listsOfDbObjectList =
            new ArrayList<MyArrayList<? extends DBInterface>>();

    public AbstractXStreamHelper(DataPool pool) {
        this.dataPool = pool;
        xstream.setMode(XStream.ID_REFERENCES);
        // not possible for us because we have circular references xstream.setMode(XStream.NO_REFERENCES);
        // see http://article.gmane.org/gmane.comp.java.xstream.user/5379

        // the following does not work for importing
        //xstream.aliasField("objId", DbObject.class, "id");
        //xstream.useAttributeFor(DbObject.class, "id");

        xstream.aliasAttribute("ref", "reference");

//        xstream.registerConverter(new DbObjectConverter(xstream.getMapper(),
//                xstream.getReflectionProvider()));
//        xstream.setMarshallingStrategy(new ReusingReferenceByIdMarshallingStrategy());

        xstream.alias("role", Role.class);
        xstream.alias("person", Person.class);
        xstream.alias("location", Location.class);
        xstream.alias("event", Event.class);
        xstream.alias("feature", Feature.class);

        // add type as attribute to ArrayList export
        xstream.alias("mylist", MyArrayList.class);
        xstream.alias("settings", DataPoolSettings.class);
        
        //xstream.addImplicitCollection(MyArrayList.class, "mylist");
        xstream.useAttributeFor(MyArrayList.class, "type");
    }

    public DataPool getDataPool() {
        return dataPool;
    }

    public void doWork() throws IOException {
        xStreamReader.readXml();
    }

    protected static interface XStreamReadFromXml {

        void readXml() throws IOException;
    }

    protected static class MyArrayList<T extends DBInterface> {

        private static final long serialVersionUID = 2093964264607896898L;
        private Class type;
        private List<T> list;

        public MyArrayList(Dao<T> dao) {
            setType(dao.getType());
            list = new ArrayList<T>();
            for (T obj : dao.getAll()) {
                list.add(obj);
            }
        }

        public List<T> getList() {
            return list;
        }

        public void setList(List<T> list) {
            this.list = list;
        }

        public void setType(Class type) {
            this.type = type;
        }

        public Class getType() {
            return type;
        }
    }
}
