/*
 *  Copyright 2009 Peter Karich, peat_hal 'at' users 'dot' sourceforge 'dot' net.
 * 
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 * 
 *       http://www.apache.org/licenses/LICENSE-2.0
 * 
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *  under the License.
 */
package de.timefinder.core.io.xml;

import de.pannous.xvantage.core.Xvantage;
import de.timefinder.algo.DataPoolSettings;
import de.timefinder.algo.constraint.EventOrderConstraint;
import de.timefinder.algo.constraint.RasterConstraint;
import de.timefinder.data.DBInterface;
import de.timefinder.data.DataPool;
import de.timefinder.data.Feature;
import de.timefinder.data.access.Dao;
import java.util.Map;
import java.util.Set;
import java.util.logging.Level;
import javolution.util.FastMap;
import javolution.util.FastSet;

/**
 * @author Peter Karich, peat_hal 'at' users 'dot' sourceforge 'dot' net
 */
public class AbstractXvantageHelper {

    protected Xvantage xvantage = new Xvantage();
    protected de.pannous.xvantage.core.DataPool xPool;

    public AbstractXvantageHelper(final DataPool tfPool) {
        for (Dao<? extends DBInterface> dao : tfPool.getDaos()) {
            xvantage.mount("/root/" + de.pannous.xvantage.core.util.Helper.getJavaModifier(dao.getType().getSimpleName()) + "s/",
                    dao.getType());
        }
        xvantage.mount("/root/settings", SimpleDataPoolSettings.class);

        xvantage.ignoreMethod(Feature.class, "getEvents");
        // save some disc space
        xvantage.setSkipNullProperty(true);
        xvantage.setLogLevel(Level.WARNING);
        // use javolution stuff
        xvantage.setDefaultImplementation(Map.class, FastMap.class);
        xvantage.setDefaultImplementation(Set.class, FastSet.class);
        xvantage.putAlias(RasterConstraint.class, "RasterConstraint");
        xvantage.putAlias(EventOrderConstraint.class, "OrderConstraint");
    }
}
