/*
 *  Copyright 2009 Peter Karich, peat_hal ‘at’ users ‘dot’ sourceforge ‘dot’ net.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *  under the License.
 */
package de.timefinder.core.io.xml;

import de.timefinder.algo.DataPoolSettings;
import de.timefinder.data.DataPool;
import de.timefinder.data.Event;
import de.timefinder.data.Feature;
import de.timefinder.data.Location;
import de.timefinder.data.Person;
import de.timefinder.data.access.LocationDao;
import de.timefinder.data.access.PersonDao;
import java.io.IOException;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.io.Writer;
import java.util.ArrayList;

/**
 * @author Peter Karich, peat_hal ‘at’ users ‘dot’ sourceforge ‘dot’ net
 */
public class ExportXmlXStream extends AbstractXStreamHelper {

    public ExportXmlXStream(DataPool pool, final DataPoolSettings settings, final Writer writer) throws IOException {
        super(pool);
        init(settings, writer);
    }

    public ExportXmlXStream(DataPool pool, DataPoolSettings settings, final OutputStream out) throws IOException {
        super(pool);
        init(settings, out);
    }

    protected void init(final DataPoolSettings settings, final Object out) {
        xStreamReader = new XStreamReadFromXml() {

            @Override
            public void readXml() throws IOException {
                initSerializableList();
                Object[] objs = new Object[]{settings, listsOfDbObjectList};
                if (out instanceof Writer) {
                    Writer w = (Writer) out;
                    xstream.toXML(objs, w);
                    w.close();
                } else {
                    OutputStream outS = (OutputStream) out;
                    xstream.toXML(objs, (OutputStream) outS);
                    outS.close();
                }
            }
        };
    }

    @SuppressWarnings("unchecked")
    private void initSerializableList() {
        listsOfDbObjectList.clear();
        PersonDao pDao = (PersonDao) dataPool.getDao(Person.class);

        // Remove bidirectional dependencies to avoid deep nesting
        // This has to be un do after reading the xml
        for (Person person : pDao.getAll()) {
            // new ArrayList to avoid ConcurrentModificationException
            for (Event ev : new ArrayList<Event>(person.getEventsMap().keySet())) {
                person.removeEvent(ev, false);
            }
        }
        listsOfDbObjectList.add(new MyArrayList<Person>(pDao));

        listsOfDbObjectList.add(new MyArrayList<Feature>(dataPool.getDao(Feature.class)));

        LocationDao lDao = (LocationDao) dataPool.getDao(Location.class);
        for (Location loc : lDao.getAll()) {
            // new ArrayList to avoid ConcurrentModificationException
            for (Event ev : new ArrayList<Event>(loc.getEvents())) {
                loc.removeEvent(ev, false);
            }
        }
        listsOfDbObjectList.add(new MyArrayList<Location>(lDao));

        listsOfDbObjectList.add(new MyArrayList<Event>(dataPool.getDao(Event.class)));
    }
}

