/*
 * Copyright 2008 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package de.timefinder.core.ui;

import java.awt.Color;
import javax.swing.UIManager;
import org.springframework.beans.factory.InitializingBean;
import org.springframework.richclient.application.config.UIManagerConfigurer;
import org.springframework.richclient.util.Assert;

/**
 * @author Peter Karich, peat_hal ‘at’ users ‘dot’ sourceforge ‘dot’ net
 */
public class LookConfigurer implements InitializingBean {

    private UIManagerConfigurer configurer;
    private String lAndF;

    public LookConfigurer() {
        this(new UIManagerConfigurer());
    }

    public LookConfigurer(UIManagerConfigurer configurer) {
        Assert.notNull(configurer);
        this.configurer = configurer;
    }

    public void setLookAndFeel(String str) {
        lAndF = str;
    }

    public void afterPropertiesSet() throws Exception {
        //try this for nimbus:
        //UIManager.put("control", Color.BLUE);
        //UIManager.put("nimbusBase", Color.WHITE);
        //UIManager.put("nimbusBlueGrey", new Color(...));
        //UIManager.put("nimbusLightBackground", Color.GREEN);
        //http://java.sun.com/docs/books/tutorial/uiswing/lookandfeel/info.html
        
        try {
            if (lAndF != null)
                configurer.setLookAndFeel(lAndF);
            else
                configurer.setLookAndFeel(UIManager.getCrossPlatformLookAndFeelClassName());
        } catch (Exception ex) {
            configurer.setLookAndFeel(UIManager.getCrossPlatformLookAndFeelClassName());
        }
    }
}
