/*
 *  Copyright 2009 Peter Karich, peat_hal ‘at’ users ‘dot’ sourceforge ‘dot’ net.
 * 
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 * 
 *       http://www.apache.org/licenses/LICENSE-2.0
 * 
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *  under the License.
 */
package de.timefinder.core.ui.form;

import de.timefinder.data.DBInterface;
import de.timefinder.data.access.Dao;
import de.timefinder.core.util.Translator;
import org.springframework.richclient.application.event.LifecycleApplicationEvent;
import org.springframework.richclient.dialog.CloseAction;
import org.springframework.richclient.dialog.ConfirmationDialog;
import org.springframework.richclient.dialog.FormBackedDialogPage;
import org.springframework.richclient.dialog.TitledPageApplicationDialog;
import org.springframework.richclient.form.Form;
import org.springframework.richclient.util.Assert;

/**
 * @author Peter Karich, peat_hal ‘at’ users ‘dot’ sourceforge ‘dot’ net
 * @deprecated Use CollectionMasterDetailsForm instead
 */
public class TimeFinderDetailsDialog<T extends DBInterface> extends TitledPageApplicationDialog {

    // The form that allows for editing the contact.
    private Form form;
    // Are we creating a new DbObject or editing an existing one?
    private boolean creatingNew = false;
    // The data store holding all our contacts, used to add a new contact.
    private Dao<T> dataStore;
    private Translator tr;
    private String entityName;

    public TimeFinderDetailsDialog(Dao<T> dataStore, Form form) {
        Assert.notNull(dataStore, "The data store is required to edit a DbObject");
        this.form = form;
        this.dataStore = dataStore;
        entityName = dataStore.getType().getSimpleName().toLowerCase();       
        setCloseAction(CloseAction.DISPOSE);
        setDialogPage(new FormBackedDialogPage(form));
    }

    public void setTranslator(Translator translator) {
        tr = translator;
    }

    @SuppressWarnings("unchecked")
    private T getEditingObject() {
        return (T) form.getFormModel().getFormObject();
    }

    @Override
    protected void onAboutToShow() {        
        if (creatingNew) {
            setTitle(tr.get(entityName + "Properties.new.title"));
        } else {
            T obj = getEditingObject();
            String title = tr.get(entityName + "Properties.edit.title",
                    new Object[]{obj.getName()});
            setTitle(title);
        }
    }

    @Override
    protected boolean onFinish() {
        // commit any buffered edits to the model
        form.getFormModel().commit();
        // Update the persistent store with the new/modified object.
        String eventType;
        if (creatingNew) {
            eventType = LifecycleApplicationEvent.CREATED;
            dataStore.attach(getEditingObject());
        } else {
            eventType = LifecycleApplicationEvent.MODIFIED;
        }
        // And notify the rest of the application of the change
        getApplicationContext().publishEvent(new LifecycleApplicationEvent(
                eventType, getEditingObject()));
        return true;
    }

    @Override
    protected void onCancel() {
        // TODO change to person or room
        // Warn the user if they are about to discard their changes
        if (form.getFormModel().isDirty()) {
            String msg = tr.get("properties.dirtyCancelMessage");
            String title = tr.get("properties.dirtyCancelTitle");
            ConfirmationDialog dlg = new ConfirmationDialog(title, msg) {

                @Override
                protected void onConfirm() {
                    TimeFinderDetailsDialog.super.onCancel();
                }
            };
            dlg.showDialog();
        } else {
            super.onCancel();
        }
    }
}
