/*
 *  Copyright 2009 Peter Karich, peat_hal ‘at’ users ‘dot’ sourceforge ‘dot’ net.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *  under the License.
 */
package de.timefinder.core.util;

import de.timefinder.data.DataPool;
import de.timefinder.data.Event;
import de.timefinder.data.Location;
import de.timefinder.data.Person;
import de.timefinder.data.Role;
import de.timefinder.data.access.Dao;
import java.util.Map.Entry;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * @author Peter Karich, peat_hal 'at' users 'dot' sourceforge 'dot' net
 */
public class FixRelationShip {

    private Log logger = LogFactory.getLog(getClass());
    private DataPool dataPool;

    public FixRelationShip(DataPool dataPool) {
        this.dataPool = dataPool;
    }

    public int doWork() {
        Dao<Person> pDao = dataPool.getDao(Person.class);
        Dao<Event> eDao = dataPool.getDao(Event.class);
        Dao<Location> lDao = dataPool.getDao(Location.class);

        int counter = 0;
        for (Person person : pDao.getAll()) {
//            logger.info(person + " events:" + person.getEventsMap().size());
            for (Entry<Event, Role> eEntry : person.getEventsMap().entrySet()) {
                if (!eEntry.getKey().getPersons().contains(person)) {
                    logger.debug("Add " + eEntry.getKey() + " to " + person + " Role:" + eEntry.getValue());
                    counter++;
                    eEntry.getKey().addPerson(person, eEntry.getValue(), true);
                }
            }
        }

        for (Event event : eDao.getAll()) {
            if (event.getLocation() != null) {
                if (event.getLocation().getEvents().contains(event)) {
                    logger.error("location " + event.getLocation() + " already has event: " + event);
                } else {
                    counter++;
                    event.getLocation().addEvent(event, false);
                }
            }
//            logger.info(event + " persons:" + event.getPersonsMap().size());
            for (Entry<Person, Role> pEntry : event.getPersonsMap().entrySet()) {
                if (!pEntry.getKey().getEvents().contains(event)) {
                    logger.debug("Add " + pEntry.getKey() + " to " + event + " Role:" + pEntry.getValue());
                    counter++;
                    pEntry.getKey().addEvent(event, pEntry.getValue(), true);
                }
            }
        }

        for (Location loc : lDao.getAll()) {
//            logger.info(loc + " events:" + loc.getEvents().size());
            for (Event ev : loc.getEvents()) {
                if (ev.getLocation() != loc) {
                    logger.debug("Change location of " + ev + " from " + ev.getLocation() + " to " + loc);
                    counter++;
                    ev.setLocation(loc);
                }
            }
        }

        return counter;
    }
}
